==> yuxiaozhu_blue_clock-0.0.3.tar.gz: android/src/main/kotlin/com/blue/flutter_plugin/OpenApi.kt <==
package com.blue.flutter_plugin

import android.Manifest
import android.bluetooth.BluetoothAdapter
import android.content.pm.PackageManager
import android.os.Build
import android.util.Log
import android.widget.Toast
import androidx.annotation.RequiresApi
import androidx.appcompat.app.AppCompatActivity
import com.xunmingiot.blesdk.ble.BleLockListener
import com.xunmingiot.blesdk.ble.OpenApi
import java.util.*


class OpenApi: AppCompatActivity() {
    private var permissionOn = false
    private val bleLockListener: BleLockListener = object : BleLockListener {
        override fun onReadBleLockStatus(res: Map<String, String>) {}
        override fun onUnlock(res: Map<String, String>) {}
        override fun onFail(res: Map<String, String>) {}
        override fun onReadConfig(res: Map<String, String>) {}
        override fun onSetConfig(res: Map<String, String>) {}
        override fun onSetPassword(res: Map<String, String>) {}
    }
    @RequiresApi(Build.VERSION_CODES.M)
  public  fun onClick(view: Int, mac: String, pwd: String, config: String, newPwd: String):String{

//        checkPermission()
//        if (!permissionOn) return "没有获取到设备的蓝牙权限"

        println(mac)
        println(pwd)
        println("安卓收到的数据")
        if(isMac(mac)!=null){
            return "MAC地址不符合"
        }
        when (view) {
            1 -> {
                //获取mac和pwd
                // 1. mac地址
                // 2. password
                // 3. bleLockListener
                // return  OpenApi.getLockStatus(this, mac, password, bleLockListener)
                //                OpenApi.getLockConfig(this, mac, password, bleLockListener)
                //                val config = "11044C100A000103200B"
                //                OpenApi.setLockConfig(this, mac, password, config, bleLockListener)
                //                val oldPwd_1 = "11111111"
                //                val newPwd_1 = "00000000"
                //                OpenApi.setLockPassword(this, mac, oldPwd_1, newPwd_1, bleLockListener)
                // 4. 扫描超时时间(ms) 可不传默认25s
                // 5. config 配置(16进制字符串20位)
                // 6. 新旧密码8位字母/数字，区分大小写
                OpenApi.openLock(this, mac, pwd, bleLockListener, 10000)

            }
            2 -> {
                OpenApi.getLockStatus(this, mac, pwd, bleLockListener)
            }
            3 -> {
                OpenApi.getLockConfig(this, mac, pwd, bleLockListener)
            }
            4 -> {
                OpenApi.setLockConfig(this, mac, pwd, config, bleLockListener)
            }
            5 -> {
                OpenApi.setLockPassword(this, mac, pwd, newPwd, bleLockListener)
            }
        }
        return  mac
    }
    private fun isMac(mac: String): String? {
        return if (BluetoothAdapter.checkBluetoothAddress(mac)) {
            mac
        } else {
            null
        }
    }

    // 检查权限
    @RequiresApi(Build.VERSION_CODES.M)
    private fun checkPermission() {
        val permissionsList = ArrayList<String>()
        val permissions = arrayOf(Manifest.permission.BLUETOOTH_ADMIN, Manifest.permission.BLUETOOTH,
                Manifest.permission.ACCESS_COARSE_LOCATION,
                Manifest.permission.ACCESS_FINE_LOCATION)
        for (perm in permissions) {
            //进入到这里代表没有权限
            if (PackageManager.PERMISSION_GRANTED != checkSelfPermission(perm)) permissionsList.add(perm)
        }
        if (!permissionsList.isEmpty()) {
            permissionOn = false
            Toast.makeText(this, "位置权限", Toast.LENGTH_SHORT).show()
            requestPermissions(permissionsList.toTypedArray(), 1)
        } else {
            permissionOn = true
        }
    }
    override fun onRequestPermissionsResult(requestCode: Int, permissions: Array<String>, grantResults: IntArray) {
        var content = "动态授权的回调:"
        for (i in permissions.indices) {
            content += """
            
            权限${permissions[i]}【${if (grantResults[i] != -1) "允许" else "拒绝"}】
            """.trimIndent()
        }
    }
}

==> yuxiaozhu_blue_clock-0.1.4.tar.gz: android/src/main/kotlin/com/blue/flutter_plugin/OpenApi.kt <==
package com.blue.flutter_plugin

import android.Manifest
import android.bluetooth.BluetoothAdapter
import android.content.pm.PackageManager
import android.os.Build
import android.os.Bundle
import android.widget.Toast
import androidx.annotation.RequiresApi
import androidx.appcompat.app.AppCompatActivity
import com.xunmingiot.blesdk.ble.BleLockListener
import com.xunmingiot.blesdk.ble.OpenApi
import java.util.*


class OpenApiActivity: AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
    }

    private var permissionOn = false
    private val bleLockListener: BleLockListener = object : BleLockListener {
        override fun onReadBleLockStatus(res: Map<String, String>) {}
        override fun onUnlock(res: Map<String, String>) {}
        override fun onFail(res: Map<String, String>) {}
        override fun onReadConfig(res: Map<String, String>) {}
        override fun onSetConfig(res: Map<String, String>) {}
        override fun onSetPassword(res: Map<String, String>) {}
    }
    @RequiresApi(Build.VERSION_CODES.M)
    fun onClick(view: Int, mac: String, password: String, config: String, newPwd: String):String{


        when (view) {
            1 -> {
                //获取mac和pwd
                // 1. mac地址
                // 2. password
                // 3. bleLockListener
                // return  OpenApi.getLockStatus(this, mac, password, bleLockListener)
                //                OpenApi.getLockConfig(this, mac, password, bleLockListener)
                //                val config = "11044C100A000103200B"
                //                OpenApi.setLockConfig(this, mac, password, config, bleLockListener)
                //                val oldPwd_1 = "11111111"
                //                val newPwd_1 = "00000000"
                //                OpenApi.setLockPassword(this, mac, oldPwd_1, newPwd_1, bleLockListener)
                // 4. 扫描超时时间(ms) 可不传默认25s
                // 5. config 配置(16进制字符串20位)
                // 6. 新旧密码8位字母/数字，区分大小写
                println("进来开锁")
                return OpenApi.openLock(this@OpenApiActivity, mac, password, bleLockListener, 10000).toString()

            }
            2 -> {
                return OpenApi.getLockStatus(this, mac, password, bleLockListener).toString()
            }
            3 -> {
                return OpenApi.getLockConfig(this, mac, password, bleLockListener).toString()
            }
            4 -> {
                return OpenApi.setLockConfig(this, mac, password, config, bleLockListener).toString()
            }
            5 -> {
                return OpenApi.setLockPassword(this, mac, password, newPwd, bleLockListener).toString()
            }
        }
        return  mac
    }
    private fun isMac(mac: String): String? {
        return if (BluetoothAdapter.checkBluetoothAddress(mac)) {
            mac
        } else {
            null
        }
    }

    // 检查权限
    @RequiresApi(Build.VERSION_CODES.M)
    private fun checkPermission() {
        val permissionsList = ArrayList<String>()
        val permissions = arrayOf(Manifest.permission.BLUETOOTH_ADMIN, Manifest.permission.BLUETOOTH,
                Manifest.permission.ACCESS_COARSE_LOCATION,
                Manifest.permission.ACCESS_FINE_LOCATION)
        for (perm in permissions) {
            //进入到这里代表没有权限
            if (PackageManager.PERMISSION_GRANTED != checkSelfPermission(perm)) permissionsList.add(perm)
        }
        if (!permissionsList.isEmpty()) {
            permissionOn = false
            Toast.makeText(this, "位置权限", Toast.LENGTH_SHORT).show()
            requestPermissions(permissionsList.toTypedArray(), 1)
        } else {
            permissionOn = true
        }
    }
    override fun onRequestPermissionsResult(requestCode: Int, permissions: Array<String>, grantResults: IntArray) {
        var content = "动态授权的回调:"
        for (i in permissions.indices) {
            content += """
            
            权限${permissions[i]}【${if (grantResults[i] != -1) "允许" else "拒绝"}】
            """.trimIndent()
        }
    }
}
